@@ -89,6 +89,13 @@
     --- 新增功能 滚动栏(RollWidget)
     --- ListWidget 新增一种动画效果
     --- 新增 说明 流式布局 无法 配合 QScrollArea 使用
+2023.1.14 1.2.13.6
+    --- 重新修改了标题栏的继承方式
+    --- 更新 无边框窗口 的代码,修复无边框窗口在作为子窗口时,不显示的BUG,
+        并失去做为主窗口时的部分功能
+    --- 新增了一个 动态标题输入框(DynamicTLine)
+    --- 对流式布局进行了优化
+    --- 移除了 内置样式设计器的 controlConfig.json 改为 controlConfig.py
 '''
 
 # ===============================================
